@@ -3,14 +3,15 @@
 #'
 #' This function calls \code{parcor_ijk} function which
 #' uses original data to compute
-#' generalized partial correlations between \eqn{X_i} and \eqn{X_j}
+#' generalized partial correlations between \eqn{X_{idep}} and \eqn{X_j}
 #' where j can be any one of the remaining
-#' variables in the input matrix denoted as \eqn{x_k}. Calculation 
-#' allows for the presence of control variable(s) if any outside
-#' the input matrix.
+#' variables in the input matrix \code{mtx}. Partial correlations remove the effect of
+#' variables \eqn{x_k} other than \eqn{X_i} and \eqn{X_j}. Calculation further 
+#' allows for the presence of control variable(s) (if any) to remain always outside
+#' the input matrix and whose effect is also removed in computing partial correlations.
 #' 
 #'
-#' @param mtx {Input data matrix.}
+#' @param mtx {Input data matrix with at least 3 columns.}
 #' @param ctrl {Input vector or matrix of data for control variable(s), 
 #'     default is ctrl=0 when control variables are absent}
 #' @param dig The number of digits for reporting (=4, default)
@@ -20,8 +21,6 @@
 #'   has the name of the \code{idep} variable. The
 #'    second column has the name of the j variable, while the third column 
 #'    has partial correlation coefficients  r*(i,j | k).
-#'   The 4-th column has  r*(j,i | k) (denoted partji), and the 5-th column has rijMrji,
-#'   that is the difference in absolute values (abs(partij) - abs(partji)).
 #'
 #' @note We want to get all partial
 #'  correlation coefficients. 
@@ -79,7 +78,7 @@ parcorMany <- function(mtx, ctrl=0, dig = 4, idep = 1, verbo = FALSE) {
             ii = ii + 1
             partij[ii] = p1$ouij
             partji[ii] = p1$ouji
-        }  #end i lop
+        }  #end i loop
      rijMrji = (abs(partij) - abs(partji))
     cb1 = cbind(partij, partji, rijMrji)
     cb2 = apply(cb1, 2, round, dig)
