@@ -1,6 +1,6 @@
 #' Silently compute generalized (ridge-adjusted) partial correlation coefficients from matrix R*.
 #'
-#' This function calls \code{parcor_ijk} function which
+#' This function calls \code{parcor_ijkOLD} function which
 #' uses a generalized correlation matrix R* as input to compute
 #' generalized partial correlations between \eqn{X_i} and \eqn{X_j}
 #' where j can be any one of the remaining
@@ -29,7 +29,7 @@
 #'  a suitably larger input \code{incr} to get all relevant partial
 #'  correlation coefficients in  the correct [-1,1] interval. 
 #' @author Prof. H. D. Vinod, Economics Dept., Fordham University, NY.
-#' @seealso See Also \code{\link{parcor_ijk}}.
+#' @seealso See Also \code{\link{parcor_ijk}} for a better version using original data as input.
 #' @keywords partial correlations, ridge biasing factor,
 #' @references Vinod, H. D. 'Generalized Correlations and Instantaneous
 #'  Causality for Data Pairs Benchmark,' (March 8, 2015)
@@ -49,7 +49,7 @@
 #' y=1+2*x+3*z+rnorm(10)# y depends on x and z not vice versa
 #' mtx=cbind(x,y,z)
 #' g1=gmcmtx0(mtx)
-#' parcor_ijk(g1,1,2) # ouji> ouij implies i=x is the cause of j=y
+#' parcor_ijkOLD(g1,1,2) # ouji> ouij implies i=x is the cause of j=y
 #' parcor_ridg(g1,idep=1)
 #' parcorSilent(g1,idep=1)
 #'  
@@ -67,7 +67,7 @@ parcorSilent <- function(gmc0, dig = 4, idep = 1, verbo = FALSE, incr = 3) {
     n = NROW(gmc0)
     p = NCOL(gmc0)
     if (n != p) 
-        stop("gmc0 is not square matrix")
+        stop("gmc0 is not a square matrix")
 #    nam = colnames(gmc0)  #R makes nam=NULL of lenghth 0 if gmc0 column names Missing
 #    if (length(nam) == 0) 
 #        nam = paste("V", 1:p, sep = "")
@@ -104,7 +104,7 @@ parcorSilent <- function(gmc0, dig = 4, idep = 1, verbo = FALSE, incr = 3) {
         partji = rep(NA, n - 1)
         ii = 0
         for (i in 2:n) {
-            p1 = parcor_ijk(gmc1, 1, i)
+            p1 = parcor_ijkOLD(gmc1, 1, i)
             ii = ii + 1
             partij[ii] = p1$ouij
             partji[ii] = p1$ouji
