@@ -1,6 +1,6 @@
-#' Compute generalized (ridge-adjusted) partial correlation coefficients from matrix R*.
+#' Compute generalized (ridge-adjusted) partial correlation coefficients from matrix R*. (deprecated)
 #'
-#' This function calls \code{parcor_ijk} function which
+#' This function calls \code{parcor_ijkOLD} function which
 #' uses a generalized correlation matrix R* as input to compute
 #' generalized partial correlations between \eqn{X_i} and \eqn{X_j}
 #' where j can be any one of the remaining
@@ -30,7 +30,7 @@
 #'  a suitably larger input \code{incr} to get all relevant partial
 #'  correlation coefficients in  the correct [-1,1] interval. 
 #' @author Prof. H. D. Vinod, Economics Dept., Fordham University, NY.
-#' @seealso See Also \code{\link{parcor_ijk}}.
+#' @seealso See Also \code{\link{parcor_ijkOLD}}.
 #' @keywords partial correlations
 #' @references Vinod, H. D. 'Generalized Correlations and Instantaneous
 #'  Causality for Data Pairs Benchmark,' (March 8, 2015)
@@ -50,7 +50,7 @@
 #' y=1+2*x+3*z+rnorm(10)# y depends on x and z not vice versa
 #' mtx=cbind(x,y,z)
 #' g1=gmcmtx0(mtx)
-#' parcor_ijk(g1,1,2) # ouji> ouij implies i=x is the cause of j=y
+#' parcor_ijkOLD(g1,1,2) # ouji> ouij implies i=x is the cause of j=y
 #' parcor_ridg(g1,idep=1)
 #'  
 #'    
@@ -84,11 +84,11 @@ parcor_ridg <- function(gmc0, dig = 4, idep = 1, verbo = FALSE, incr = 3) {
     print(c("increment=", diff.e0))
     # diff.e0=round(diff.e0,3)
     if (diff.e0 == 0) {
-        print("difference between consecutive eigenvalues is zero")
+        print("difference between cosecutive eigenvalues is zero")
         diff.e0 = incr * (sort.abse0[3] - sort.abse0[1])
     }
     if (diff.e0 == 0) {
-        print("difference between consecutive eigenvalues still zero")
+        print("difference between cosecutive eigenvalues still zero")
         diff.e0 = incr * (sort.abse0[4] - sort.abse0[1])
     }
     
@@ -126,7 +126,7 @@ parcor_ridg <- function(gmc0, dig = 4, idep = 1, verbo = FALSE, incr = 3) {
             if (i == n) {
                 print(c("partial r* between", nam[1], nam[i]))
             }
-            p1 = parcor_ijk(gmc1, 1, i)
+            p1 = parcor_ijkOLD(gmc1, 1, i)
             ii = ii + 1
             partij[ii] = p1$ouij
             partji[ii] = p1$ouji
